#ifndef MY_DEVICES_H
#define	MY_DEVICES_H


/**
 * @brief Read one byte from a 1-wire device like a DS2413
 * @param address The device address string
 * @param file The file in the address space
 * @return The read value or negative value if error
 */
int read_w1(char *address, char *file);
int write_w1(char *address, char *file, uint8_t val);

int device_out(char *uuid, int value);
int device_in(char *uuid, int *value);

/**
 * @brief Set present status
 * @param address The device address string
 * @param present The desired present value
 * @return -1 if error. 0 if ok and 1 if ok and changed.
 */
int device_present(char *address, int present);

/**
 * @brief Return json object for one device.
 * @param device The device record.
 * @return json_object with data.
 */
json_object *device_json_object(devices_list *device);

/**
 * @brief Broadcast all devices to connected websockets.
 */
void devices_ws(void);

int devices_detect(void);

void *my_devices_loop(void *);

#endif
